@@ -46,10 +46,10 @@ QString proposalComment(const KCalCore::Incidence::Ptr &incidence)
 
     switch (incidence->type()) {
     case KCalCore::IncidenceBase::TypeEvent: {
-        const KDateTime dtEnd = incidence->dateTime(KCalCore::Incidence::RoleDisplayEnd);
+        const QDateTime dtEnd = incidence->dateTime(KCalCore::Incidence::RoleDisplayEnd);
         comment = i18n("Proposed new meeting time: %1 - %2",
-                       KCalUtils::IncidenceFormatter::dateToString(incidence->dtStart()),
-                       KCalUtils::IncidenceFormatter::dateToString(dtEnd));
+                       KCalUtils::IncidenceFormatter::dateToString(incidence->dtStart().toLocalTime().date()),
+                       KCalUtils::IncidenceFormatter::dateToString(dtEnd.toLocalTime().date()));
     }
     break;
     case KCalCore::IncidenceBase::TypeTodo: {
@@ -396,7 +396,7 @@ void ITIPHandlerHelper::sendIncidenceDeletedMessage(KCalCore::iTIPMethod method,
         askDelegator->openDialogIncidenceDeleted(ITIPHandlerDialogDelegate::Organizer, question, mDefaultAction,
                 KGuiItem(i18nc("@action:button dialog positive answer", "Send Update")));
         return;
-    } else if (incidence->type() == KCalCore::Incidence::TypeEvent) {
+    } else {
 
         const QStringList myEmails = Akonadi::CalendarUtils::allEmails();
         bool incidenceAcceptedBefore = false;
